pub struct SettingsFrame {
pub header_table_size: u32,
pub enable_push: bool,
pub initial_window_size: u32,
pub max_header_list_size: u32,
}Expand description
Initial HTTP/2 SETTINGS frame parameters.
The values and the order in which they are sent are used by Akamai and other WAFs to identify the client implementation.
Fields
header_table_size: u32SETTINGS_HEADER_TABLE_SIZE (ID 0x1).
enable_push: boolSETTINGS_ENABLE_PUSH (ID 0x2).
initial_window_size: u32SETTINGS_INITIAL_WINDOW_SIZE (ID 0x4).
max_header_list_size: u32SETTINGS_MAX_HEADER_LIST_SIZE (ID 0x6).